package ch.rakudave.jnetmap.net.status;

import java.io.IOException;
import java.net.ConnectException;
import java.net.InetAddress;
import java.net.Socket;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * @author rakudave
 */

@XStreamAlias("OpenSocket")
public class OpenSocket implements PingMethod {
	private int port;
	
	public OpenSocket() throws IllegalArgumentException {
		this(0);
	}
	public OpenSocket(int port) throws IllegalArgumentException {
		if (port < 0 | port > 65535) throw new IllegalArgumentException();
		this.port = port;
	}

	@Override
	public Status getStatus(InetAddress address) {
		try {
			Socket sock = new java.net.Socket(address, port);
			sock.close();
			return Status.UP;
		} catch (ConnectException e) {
			return Status.DOWN;
		} catch (IOException e) {
			return Status.UNKNOWN;
		}
	}
	
	public int getPort() {
		return port;
	}
	
	@Override
	public String toString() {
		return "TCP Port";
	}
}
